@@ -6,19 +6,15 @@
 
 #include "gitwrapper.h"
 
-#include <QTextCodec>
-
-GitWrapper* GitWrapper::m_instance = nullptr;
+GitWrapper *GitWrapper::m_instance = nullptr;
 const int GitWrapper::BUFFER_SIZE = 256;
 const int GitWrapper::SMALL_BUFFER_SIZE = 128;
 
 GitWrapper::GitWrapper()
 {
-    m_localCodec = QTextCodec::codecForLocale();
 }
 
-
-GitWrapper* GitWrapper::instance()
+GitWrapper *GitWrapper::instance()
 {
     if (m_instance == nullptr) {
         m_instance = new GitWrapper();
@@ -39,7 +35,7 @@ QString GitWrapper::userName()
     m_process.start(QStringLiteral("git"), {QStringLiteral("config"), QStringLiteral("--get"), QStringLiteral("user.name")});
     while (m_process.waitForReadyRead()) {
         if (m_process.readLine(buffer, sizeof(buffer)) > 0) {
-            result = m_localCodec->toUnicode(buffer).trimmed();
+            result = QString::fromLocal8Bit(buffer).trimmed();
         }
     }
     return result;
@@ -52,14 +48,13 @@ QString GitWrapper::userEmail()
     m_process.start(QStringLiteral("git"), {QStringLiteral("config"), QStringLiteral("--get"), QStringLiteral("user.email")});
     while (m_process.waitForReadyRead()) {
         if (m_process.readLine(buffer, sizeof(buffer)) > 0) {
-            result = m_localCodec->toUnicode(buffer).trimmed();
+            result = QString::fromLocal8Bit(buffer).trimmed();
         }
     }
     return result;
 }
 
-
-QStringList GitWrapper::branches(int* currentBranchIndex)
+QStringList GitWrapper::branches(int *currentBranchIndex)
 {
     QStringList result;
     if (currentBranchIndex != nullptr) {
@@ -68,12 +63,12 @@ QStringList GitWrapper::branches(int* currentBranchIndex)
     m_process.start(QStringLiteral("git"), {QStringLiteral("branch"), QStringLiteral("-a")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
-        while (m_process.readLine(buffer, sizeof(buffer)) > 0){
-            const QString branchName = m_localCodec->toUnicode(buffer).mid(2).trimmed();
-            //don't list non-branches and HEAD-branches directly pointing to other branches
+        while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
+            const QString branchName = QString::fromLocal8Bit(buffer).mid(2).trimmed();
+            // don't list non-branches and HEAD-branches directly pointing to other branches
             if (!branchName.contains(QLatin1String("->")) && !branchName.startsWith(QLatin1Char('('))) {
                 result.append(branchName);
-                if (currentBranchIndex !=nullptr && buffer[0]=='*') {
+                if (currentBranchIndex != nullptr && buffer[0] == '*') {
                     *currentBranchIndex = result.size() - 1;
                 }
             }
@@ -82,13 +77,13 @@ QStringList GitWrapper::branches(int* currentBranchIndex)
     return result;
 }
 
-void GitWrapper::tagSet(QSet<QString>& result)
+void GitWrapper::tagSet(QSet<QString> &result)
 {
     m_process.start(QStringLiteral("git"), {QStringLiteral("tag")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
-        while (m_process.readLine(buffer, sizeof(buffer)) > 0){
-            const QString tagName = m_localCodec->toUnicode(buffer).trimmed();
+        while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
+            const QString tagName = QString::fromLocal8Bit(buffer).trimmed();
             result.insert(tagName);
         }
     }
@@ -100,8 +95,8 @@ QStringList GitWrapper::tags()
     m_process.start(QStringLiteral("git"), {QStringLiteral("tag")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
-        while (m_process.readLine(buffer, sizeof(buffer)) > 0){
-            const QString tagName = m_localCodec->toUnicode(buffer).trimmed();
+        while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
+            const QString tagName = QString::fromLocal8Bit(buffer).trimmed();
             result.append(tagName);
         }
     }
@@ -114,7 +109,7 @@ inline QStringList GitWrapper::remotes(QLatin1String lineEnd)
     m_process.start(QStringLiteral("git"), {QStringLiteral("remote"), QStringLiteral("-v")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
-        while (m_process.readLine(buffer, sizeof(buffer)) > 0){
+        while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
             const QString line = QString::fromLocal8Bit(buffer).simplified();
             if (line.endsWith(lineEnd)) {
                 result.append(line.section(QLatin1Char(' '), 0, 0));
@@ -144,10 +139,9 @@ QString GitWrapper::lastCommitMessage()
         QStringList message;
         while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
             const QString currentLine = QString::fromLocal8Bit(buffer);
-            if (inMessage){
-                message << m_localCodec->toUnicode(buffer).trimmed();
-            }
-            else if (currentLine.startsWith(QLatin1String("Date:"))) {
+            if (inMessage) {
+                message << QString::fromLocal8Bit(buffer).trimmed();
+            } else if (currentLine.startsWith(QLatin1String("Date:"))) {
                 m_process.readLine();
                 inMessage = true;
             }
